@@ -1,8 +1,9 @@
 from hatch.project.core import Project
+from hatchling.utils.constants import DEFAULT_BUILD_SCRIPT
 
 
 def test_show_dynamic(hatch, temp_dir):
-    project_name = 'My App'
+    project_name = 'My.App'
 
     with temp_dir.as_cwd():
         hatch('new', project_name)
@@ -17,13 +18,31 @@ def test_show_dynamic(hatch, temp_dir):
 
 
 def test_set_dynamic(hatch, helpers, temp_dir):
-    project_name = 'My App'
+    project_name = 'My.App'
 
     with temp_dir.as_cwd():
         hatch('new', project_name)
 
     path = temp_dir / 'my-app'
 
+    project = Project(path)
+    config = dict(project.raw_config)
+    config['tool']['hatch']['metadata'] = {'hooks': {'custom': {}}}
+    project.save_config(config)
+
+    build_script = path / DEFAULT_BUILD_SCRIPT
+    build_script.write_text(
+        helpers.dedent(
+            """
+            from hatchling.metadata.plugin.interface import MetadataHookInterface
+
+            class CustomMetadataHook(MetadataHookInterface):
+                def update(self, metadata):
+                    pass
+            """
+        )
+    )
+
     with path.as_cwd():
         result = hatch('version', 'minor,rc')
 
@@ -43,7 +62,7 @@ def test_set_dynamic(hatch, helpers, temp_dir):
 
 
 def test_show_static(hatch, temp_dir):
-    project_name = 'My App'
+    project_name = 'My.App'
 
     with temp_dir.as_cwd():
         hatch('new', project_name)
@@ -64,7 +83,7 @@ def test_show_static(hatch, temp_dir):
 
 
 def test_set_static(hatch, helpers, temp_dir):
-    project_name = 'My App'
+    project_name = 'My.App'
 
     with temp_dir.as_cwd():
         hatch('new', project_name)
